@@ -1,8 +1,9 @@
 """Contract DT tests module."""
 import pytest
+
 from hydroqc.contract import ContractDT
 
-from .tools import SkipIfBadRate, today_str, yesterday_str
+from .tools import SkipIfBadRate, today, yesterday
 
 
 class SubTestContractDT:
@@ -48,7 +49,7 @@ class SubTestContractDT:
         assert isinstance(contract.amount_saved_vs_base_rate, float)
 
         # get_hourly_energy
-        data_csv = await contract.get_hourly_energy(yesterday_str, today_str)
+        data_csv = await contract.get_hourly_energy(yesterday, today)
         first_line = next(data_csv)
         assert first_line == [
             "Contrat",
@@ -61,7 +62,7 @@ class SubTestContractDT:
         ], "Bad get_daily_energy CSV headers"
 
         # get_daily_energy
-        data_csv = await contract.get_daily_energy(yesterday_str, today_str)
+        data_csv = await contract.get_daily_energy(yesterday, today)
         first_line = next(data_csv)
         assert first_line == [
             "Contrat",
